geolocate.classes.system module — Geolocate 1.3.0 documentation

# geolocate.classes.system module

Module to deal with base operating system.

Programmed by: Dante Signal31

email: dante.signal31@gmail.com

`geolocate.classes.system.` `verify_python_version`(major_version, minor_revision)

  Check if current python interpreter version is what we need.

  Compare current interpreter version with the one is provided as needed one. If not over needed one version abort execution gracefully warning user she is trying to use an unsupported python interpreter.

  Parameters: | major_version (int) – Needed major version for Python interpreter. minor_revision (int) – Needed minor version for Python interpreter.
  Returns: | None